; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below.
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

[Command]
name = "DemonBlasterSimple"   ;Same name as above
command = y+z
time = 30

[Command]
name = "DemonBlaster"   ;Same name as above
command = ~D, B, D, F, c
time = 30

[Command]
name = "ViolentRectumSimple"   ;Same name as above
command = /$B, y+z
time = 30

[Command]
name = "ViolentRectum"   ;Same name as above
command = ~D, B, D, B, c
time = 30

[Command]
name = "MegaAirHunterSimple"   ;Same name as above
command = /$F, y+z
time = 30

[Command]
name = "MegaAirHunter"   ;Same name as above
command = ~D, F, D, F, c
time = 30

;-| Special Motions |------------------------------------------------------
[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, F, b

[Command]
name = "QCF_c"
command = ~D, F, c

[Command]
name = "QCB_a"
command = ~D, B, a

[Command]
name = "QCB_b"
command = ~D, B, b

[Command]
name = "QCB_c"
command = ~D, B, c

[Command]
name = "FDF_a"
command = ~F, D, F, a

[Command]
name = "FDF_b"
command = ~F, D, F, b

[Command]
name = "FDF_c"
command = ~F, D, F, c

[Command]
name = "DD_a"
command = ~D, D, a

[Command]
name = "DD_b"
command = ~D, D, b

[Command]
name = "DD_c"
command = ~D, D, c

[Command]
name = "DF_x"
command = /$DF, x

[Command]
name = "DF_y"
command = /$DF, y

[Command]
name = "DF_z"
command = /$DF, z

[Command]
name = "F_x"
command = /$F, x

[Command]
name = "F_y"
command = /$F, y

[Command]
name = "F_z"
command = /$F, z

[Command]
name = "B_x"
command = /$B, x

[Command]
name = "B_y"
command = /$B, y

[Command]
name = "B_z"
command = /$B, z

[Command]
name = "D_x"
command = /$D, x

[Command]
name = "D_y"
command = /$D, y

[Command]
name = "D_z"
command = /$D, z

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact
var(1) = 1

;---------------------------------------------------------------------------
;Violent Rectum (Hyper)
[State -1, Violent Rectum (Hyper)]
type = ChangeState
value = 3030
triggerall = command = "ViolentRectum" || command = "ViolentRectumSimple"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Mega Air Hunter / Hatch in The Peachces (Hyper)
[State -1, Mega Air Hunter / Hatch in The Peachces (Hyper)]
type = ChangeState
value = 3000
triggerall = command = "MegaAirHunter" || command = "MegaAirHunterSimple"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = statetype = A
trigger2 = ctrl = 1
trigger3 = (stateno = [200,299]) || (stateno = [400,699])
trigger3 = movecontact

;---------------------------------------------------------------------------
;Demon Blaster (Hyper)
[State -1, Demon Blaster (Hyper)]
type = ChangeState
value = 3050
triggerall = command = "DemonBlaster" || command = "DemonBlasterSimple"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl = 1
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = movecontact

;---------------------------------------------------------------------------
;Calling Breath (Air) (Strong Attack)
[State -1, Calling Breath (Air) (Strong Attack)]
type = ChangeState
value = 1250
triggerall = command = "QCB_c" || command = "D_z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Calling Breath (Air) (light Attack)
[State -1, Calling Breatb (Air) (Light Attack)]
type = ChangeState
value = 1230
triggerall = command = "QCB_a" || command = "D_x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Calling Breath (Air) (Medium Attack)
[State -1, Calling Breath (Air) (Medium Attack)]
type = ChangeState
value = 1240
triggerall = command = "QCB_b" || command = "D_y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Air Hunter (Strong Attack)
[State -1, Air Hunter (Strong Attack)]
type = ChangeState
value = 1220
triggerall = command = "QCF_c" || command = "F_z"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Air Hunter (Air) (Light Attack)
[State -1, Air Hunter (Air) (Light Attack)]
type = ChangeState
value = 1200
triggerall = command = "QCF_a" || command = "F_x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Air Hunter (Air) (Medium Attack)
[State -1, Air Hunter (Air) (Medium Attack)]
type = ChangeState
value = 1210
triggerall = command = "QCF_b" || command = "F_y" 
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 || stateno = 610 || stateno = 630 || stateno = 640) && movecontact

;---------------------------------------------------------------------------
;Biting Rectum (Strong Attack)
[State -1, Biting Rectum (Strong Attack)]
type = ChangeState
value = 1100
triggerall = command = "QCB_c" || command = "B_z"
trigger1 = statetype = s
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Biting Rectum (Light Attack)
[State -1, Biting Rectum (Light Attack)]
type = ChangeState
value = 1100
triggerall = command = "QCB_a" || command = "B_x"
trigger1 = statetype = s
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 400 || stateno = 410 || stateno = 430)  && movecontact

;---------------------------------------------------------------------------
;Biting Rectum (Medium Attack)
[State -1, Biting Rectum (Medium Attack)]
type = ChangeState
value = 1100
triggerall = command = "QCB_b" || command = "B_y"
trigger1 = statetype = s
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 400 || stateno = 410 || stateno = 430) && movecontact

;---------------------------------------------------------------------------
;Acid Shot (Strong Attack)
[State -1, Acid Shot (Strong Attack)]
type = ChangeState
value = 1050
triggerall = command = "FDF_c" || command = "DF_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Acid Shot (Light Attack)
[State -1, Acid Shot (Light Attack)]
type = ChangeState
value = 1030
triggerall = command = "FDF_a" || command = "DF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Acid Shot (Medium Attack)
[State -1, Acid Shot (Medium Attack)]
type = ChangeState
value = 1040
triggerall = command = "FDF_b" || command = "DF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Calling Breath (Strong Attack)
[State -1, Calling Breath (Strong Attack)]
type = ChangeState
value = 1080
triggerall = command = "DD_c" || command = "D_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Calling Breath (Light Attack)
[State -1, Calling Breath (Light Attack)]
type = ChangeState
value = 1060
triggerall = command = "DD_a" || command = "D_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Calling Breath (Medium Attack)
[State -1, Calling Breath (Medium Attack)]
type = ChangeState
value = 1070
triggerall = command = "DD_b" || command = "D_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Air Hunter (Strong Attack)
[State -1, Air Hunter (Strong Attack)]
type = ChangeState
value = 1020
triggerall = command = "QCF_c" || command = "F_z"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Air Hunter (Light Attack)
[State -1, Air Hunter (Light Attack)]
type = ChangeState
value = 1000
triggerall = command = "QCF_a" || command = "F_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Air Hunter (Medium Attack)
[State -1, Air Hunter (Medium Attack)]
type = ChangeState
value = 1010
triggerall = command = "QCF_b" || command = "F_y"
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = command = "BB" || command = "recovery" && (command = "holdback")
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Aerial Dash
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF" || command = "recovery" 
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Aerial Dash (Air)
[State -1, Aerial Dash]
type = ChangeState
value = 102
trigger1 = command = "FF" || command = "recovery"
trigger1 = statetype = A
trigger1 = ctrl
trigger1 = Pos Y < -30

;---------------------------------------------------------------------------
;Throw
[State -1, Throw]
type = ChangeState
value = 800
triggerall = command = "c"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Attack
[State -1, Stand Light Attack]
type = ChangeState
value = 200
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200 
trigger2 = time > 10

;---------------------------------------------------------------------------
;Stand Medium Attack
[State -1, Stand Medium Attack]
type = ChangeState
value = 210
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 400) && movecontact

;---------------------------------------------------------------------------
;Stand Strong Attack
[State -1, Stand Strong Attack]
type = ChangeState
value = 230
triggerall = command = "c"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact

;---------------------------------------------------------------------------
;Taunt
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Attack
[State -1, Crouching Light Attack]
type = ChangeState
value = 400
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 400
trigger2 = time > 15

;---------------------------------------------------------------------------
;Crouching Medium Attack
[State -1, Crouching Medium Attack]
type = ChangeState
value = 410
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 400) && movecontact

;---------------------------------------------------------------------------
;Crouching Strong Attack
[State -1, Crouching Strong Attack]
type = ChangeState
value = 430
triggerall = command = "c"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 400 || stateno = 410) && movecontact

;---------------------------------------------------------------------------
;Jump Light Attack
[State -1, Jump Light Attack]
type = ChangeState
value = 600
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1
trigger2 = stateno = 103 && time > 5

;---------------------------------------------------------------------------
;Jump Medium Attack
[State -1, Jump Medium Attack]
type = ChangeState
value = 610
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600) && movecontact
trigger3 = stateno = 103 && time > 5

;---------------------------------------------------------------------------
;Jump Strong Attack
[State -1, Jump Strong Attack]
type = ChangeState
value = 630
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl 
trigger2 = (stateno = 600 || stateno = 610 || stateno = 400 || stateno = 410) && movecontact
trigger3 = stateno = 103 && time > 5

;---------------------------------------------------------------------------
; Dash Guard Cancel
[State -1, |Dash Guard Cancel|]
type = ChangeState
value = 6070
triggerall = power >= 1000
triggerall = movetype = H
triggerall = statetype != A
triggerall = command = "FF" || command = "recovery" && power > 1000
trigger1 = (stateno = [150,154])